@@ -12,11 +12,11 @@ IO::Die - Namespaced, error-checked I/O
 
 =head1 VERSION
 
-Version 0.033
+Version 0.04
 
 =cut
 
-our $VERSION = '0.033';
+our $VERSION = '0.04';
 
 #----------------------------------------------------------------------
 #PROTECTED
@@ -84,9 +84,12 @@ sub __is_a_fh {
 #NOTE: Bareword file handles DO NOT WORK. (Auto-vivification does, though.)
 #
 sub open {
-    my ( $NS, $handle_r, $mode, $expr, @list ) = ( shift, \shift, @_ );
+    my ( $NS, $mode, $expr, @list ) = ( shift, @_[ 1 .. $#_ ] );
 
-    die "Avoid bareword file handles." if !ref $$handle_r && defined $$handle_r && length $$handle_r;
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $handle_r, $mode, $expr, @list ) = ( shift, \shift, @_ );
+
+    die "Avoid bareword file handles." if !ref $_[0] && defined $_[0] && length $_[0];
     die "Avoid one-argument open()." if !$mode;
 
     local ( $!, $^E );
@@ -94,7 +97,7 @@ sub open {
         if ( $mode eq '|-' or $mode eq '-|' ) {
 
             #NOTE: Avoid // for compatibility with old Perl versions.
-            my $open = CORE::open( $$handle_r, $mode );
+            my $open = CORE::open( $_[0], $mode );
             if ( !defined $open ) {
                 $NS->__THROW('Fork');
             }
@@ -106,7 +109,7 @@ sub open {
         die "Avoid most forms of two-argument open(). (See $file and its tests for allowable forms.)";
     }
 
-    return CORE::open( $$handle_r, $mode, $expr, @list ) || do {
+    my $ok = CORE::open( $_[0], $mode, $expr, @list ) or do {
         if ( $mode eq '|-' || $mode eq '-|' ) {
             my $cmd = $expr;
 
@@ -127,10 +130,15 @@ sub open {
 
         $NS->__THROW( 'FileOpen', mode => $mode, path => $expr );
     };
+
+    return $ok;
 }
 
 sub sysopen {
-    my ( $NS, $handle_r, @post_handle_args ) = ( shift, \shift, @_ );
+    my ( $NS, @post_handle_args ) = ( shift, @_[ 1 .. $#_ ] );
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $handle_r, @post_handle_args ) = ( shift, \shift, @_ );
 
     my ( $path, $mode, $perms ) = @post_handle_args;
 
@@ -138,10 +146,10 @@ sub sysopen {
 
     my $ret;
     if ( @post_handle_args < 3 ) {
-        $ret = CORE::sysopen( $$handle_r, $path, $mode );
+        $ret = CORE::sysopen( $_[0], $path, $mode );
     }
     else {
-        $ret = CORE::sysopen( $$handle_r, $path, $mode, $perms );
+        $ret = CORE::sysopen( $_[0], $path, $mode, $perms );
     }
 
     #XXX: Perl bug? $! is often set here even when $ret is truthy.
@@ -162,9 +170,11 @@ sub chroot {
         $filename = $_;
     }
 
-    return CORE::chroot($filename) || do {
+    my $ok = CORE::chroot($filename) or do {
         $NS->__THROW( 'Chroot', filename => $filename );
     };
+
+    return $ok;
 }
 
 sub chdir {
@@ -250,7 +260,10 @@ sub print {
 }
 
 sub syswrite {
-    my ( $NS, $fh, $buffer_sr, @length_offset ) = ( shift, shift, \shift, @_ );
+    my ( $NS, $fh, @length_offset ) = ( shift, shift, @_[ 1 .. $#_ ] );
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $fh, $buffer_sr, @length_offset ) = ( shift, shift, \shift, @_ );
 
     my ( $length, $offset ) = @length_offset;
 
@@ -258,17 +271,17 @@ sub syswrite {
 
     my $ret;
     if ( @length_offset > 1 ) {
-        $ret = CORE::syswrite( $fh, $$buffer_sr, $length, $offset );
+        $ret = CORE::syswrite( $fh, $_[0], $length, $offset );
     }
     elsif (@length_offset) {
-        $ret = CORE::syswrite( $fh, $$buffer_sr, $length );
+        $ret = CORE::syswrite( $fh, $_[0], $length );
     }
     else {
-        $ret = CORE::syswrite( $fh, $$buffer_sr );
+        $ret = CORE::syswrite( $fh, $_[0] );
     }
 
     if ( !defined $ret ) {
-        my $real_length = length $$buffer_sr;
+        my $real_length = length $_[0];
 
         if ($offset) {
             if ( $offset > 0 ) {
@@ -295,7 +308,10 @@ sub syswrite {
 #make it impossible not to duplicate code here.
 
 sub read {
-    my ( $NS, $fh, $buffer_sr, @length_offset ) = ( shift, shift, \shift, @_ );
+    my ( $NS, $fh, @length_offset ) = ( shift, shift, @_[ 1 .. $#_ ] );
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $fh, $buffer_sr, @length_offset ) = ( shift, shift, \shift, @_ );
 
     my ( $length, $offset ) = @length_offset;
 
@@ -307,10 +323,10 @@ sub read {
 
     my $ret;
     if ( @length_offset > 1 ) {
-        $ret = CORE::read( $fh, $$buffer_sr, $length, $offset );
+        $ret = CORE::read( $fh, $_[0], $length, $offset );
     }
     else {
-        $ret = CORE::read( $fh, $$buffer_sr, $length );
+        $ret = CORE::read( $fh, $_[0], $length );
     }
 
     if ( !defined $ret ) {
@@ -321,7 +337,10 @@ sub read {
 }
 
 sub sysread {
-    my ( $NS, $fh, $buffer_sr, @length_offset ) = ( shift, shift, \shift, @_ );
+    my ( $NS, $fh, @length_offset ) = ( shift, shift, @_[ 1 .. $#_ ] );
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $fh, $buffer_sr, @length_offset ) = ( shift, shift, \shift, @_ );
 
     my ( $length, $offset ) = @length_offset;
 
@@ -333,10 +352,10 @@ sub sysread {
 
     my $ret;
     if ( @length_offset > 1 ) {
-        $ret = CORE::sysread( $fh, $$buffer_sr, $length, $offset );
+        $ret = CORE::sysread( $fh, $_[0], $length, $offset );
     }
     else {
-        $ret = CORE::sysread( $fh, $$buffer_sr, $length );
+        $ret = CORE::sysread( $fh, $_[0], $length );
     }
 
     if ( !defined $ret ) {
@@ -350,9 +369,11 @@ sub close {
     my ( $NS, $fh ) = @_;
 
     local ( $!, $^E );
-    return ( $fh ? CORE::close($fh) : CORE::close() ) || do {
+    my $ok = ( $fh ? CORE::close($fh) : CORE::close() ) or do {
         $NS->__THROW('Close');
     };
+
+    return $ok;
 }
 
 #NOTE: See above about read/sysread; the same duplicated code problem
@@ -362,56 +383,71 @@ sub seek {
     my ( $NS, $fh, $pos, $whence ) = @_;
 
     local ( $!, $^E );
-    return CORE::seek( $fh, $pos, $whence ) || do {
+    my $ok = CORE::seek( $fh, $pos, $whence ) or do {
         $NS->__THROW( 'FileSeek', whence => $whence, position => $pos );
     };
+
+    return $ok;
 }
 
 sub sysseek {
     my ( $NS, $fh, $pos, $whence ) = @_;
 
     local ( $!, $^E );
-    return CORE::sysseek( $fh, $pos, $whence ) || do {
+    my $ok = CORE::sysseek( $fh, $pos, $whence ) or do {
         $NS->__THROW( 'FileSeek', whence => $whence, position => $pos );
     };
+
+    return $ok;
 }
 
 sub truncate {
     my ( $NS, $fh_or_expr, $length ) = @_;
 
     local ( $!, $^E );
-    return CORE::truncate( $fh_or_expr, $length ) || do {
+    my $ok = CORE::truncate( $fh_or_expr, $length ) or do {
         $NS->__THROW( 'FileTruncate', length => $length );
     };
+
+    return $ok;
 }
 
 #----------------------------------------------------------------------
 
 sub opendir {
-    my ( $NS, $dh_r, $dir ) = ( shift, \shift, shift );
+    my ( $NS, $dir ) = ( shift, @_[ 1 .. $#_ ] );
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $dh_r, $dir ) = ( shift, \shift, shift );
 
     local ( $!, $^E );
-    return CORE::opendir( $$dh_r, $dir ) || do {
+    my $ok = CORE::opendir( $_[0], $dir ) or do {
         $NS->__THROW( 'DirectoryOpen', path => $dir );
     };
+
+    return $ok;
 }
 
 sub rewinddir {
     my ( $NS, $dh ) = @_;
 
     local ( $!, $^E );
-    return CORE::rewinddir($dh) || do {
+    my $ok = CORE::rewinddir($dh) or do {
         $NS->__THROW('DirectoryRewind');
     };
+
+    return $ok;
 }
 
 sub closedir {
     my ( $NS, $dh ) = @_;
 
     local ( $!, $^E );
-    return CORE::closedir($dh) || do {
+    my $ok = CORE::closedir($dh) or do {
         $NS->__THROW('DirectoryClose');
     };
+
+    return $ok;
 }
 
 #----------------------------------------------------------------------
@@ -473,9 +509,11 @@ sub flock {
     my ( $NS, $fh, $operation ) = @_;
 
     local ( $!, $^E );
-    return CORE::flock( $fh, $operation ) || do {
+    my $ok = CORE::flock( $fh, $operation ) or do {
         $NS->__THROW( 'Flock', operation => $operation );
     };
+
+    return $ok;
 }
 
 #NOTE: This will only chmod() one thing at a time. It refuses to support
@@ -495,13 +533,15 @@ sub chmod {
     #cf. https://rt.perl.org/Ticket/Display.html?id=122703
     local ( $!, $^E );
 
-    return CORE::chmod( $mode, $target ) || do {
+    my $ok = CORE::chmod( $mode, $target ) or do {
         if ( __is_a_fh($target) ) {
             $NS->__THROW( 'Chmod', permissions => $mode );
         }
 
         $NS->__THROW( 'Chmod', permissions => $mode, path => $target );
     };
+
+    return $ok;
 }
 
 #NOTE: This will only chown() one thing at a time. It refuses to support
@@ -519,31 +559,37 @@ sub chown {
 
     local ( $!, $^E );
 
-    return CORE::chown( $uid, $gid, $target ) || do {
+    my $ok = CORE::chown( $uid, $gid, $target ) or do {
         if ( __is_a_fh($target) ) {
             $NS->__THROW( 'Chown', uid => $uid, gid => $gid );
         }
 
         $NS->__THROW( 'Chown', uid => $uid, gid => $gid, path => $target );
     };
+
+    return $ok;
 }
 
 sub link {
     my ( $NS, $old, $new ) = @_;
 
     local ( $!, $^E );
-    return CORE::link( $old, $new ) || do {
+    my $ok = CORE::link( $old, $new ) || do {
         $NS->__THROW( 'Link', oldpath => $old, newpath => $new );
     };
+
+    return $ok;
 }
 
 sub symlink {
     my ( $NS, $old, $new ) = @_;
 
     local ( $!, $^E );
-    return CORE::symlink( $old, $new ) || do {
+    my $ok = CORE::symlink( $old, $new ) or do {
         $NS->__THROW( 'SymlinkCreate', oldpath => $old, newpath => $new );
     };
+
+    return $ok;
 }
 
 sub readlink {
@@ -551,18 +597,22 @@ sub readlink {
     my $path = @_ ? shift : $_;
 
     local ( $!, $^E );
-    return CORE::readlink($path) || do {
+    my $ok = CORE::readlink($path) or do {
         $NS->__THROW( 'SymlinkRead', path => $path );
     };
+
+    return $ok;
 }
 
 sub rename {
     my ( $NS, $old, $new ) = @_;
 
     local ( $!, $^E );
-    return CORE::rename( $old, $new ) || do {
+    my $ok = CORE::rename( $old, $new ) or do {
         $NS->__THROW( 'Rename', oldpath => $old, newpath => $new );
     };
+
+    return $ok;
 }
 
 #NOTE: This will only unlink() one file at a time. It refuses to support
@@ -583,9 +633,11 @@ sub unlink {
     }
 
     local ( $!, $^E );
-    return CORE::unlink(@paths) || do {
+    my $ok = CORE::unlink(@paths) or do {
         $NS->__THROW( 'Unlink', path => $paths[0] );
     };
+
+    return $ok;
 }
 
 sub mkdir {
@@ -624,9 +676,11 @@ sub rmdir {
     }
 
     local ( $!, $^E );
-    return CORE::rmdir( $args[0] ) || do {
+    my $ok = CORE::rmdir( $args[0] ) or do {
         $NS->__THROW( 'DirectoryDelete', path => $args[0] );
     };
+
+    return $ok;
 }
 
 sub fork {
@@ -656,18 +710,25 @@ sub kill {
 sub exec {
     my ( $NS, $progname ) = @_;
 
-    exec {$progname} $progname, @_ or do {
+    my $ok = CORE::exec {$progname} $progname, @_ or do {
         $NS->__THROW( 'Exec', program => $progname, arguments => \@_ );
     };
+
+    return $ok;
 }
 
 sub pipe {
-    my ( $NS, $read_r, $write_r ) = ( shift, \shift, \shift );
+    my ($NS) = (shift);
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $read_r, $write_r ) = ( shift, \shift, \shift );
 
     local ( $!, $^E );
-    return CORE::pipe( $$read_r, $$write_r ) || do {
+    my $ok = CORE::pipe( $_[0], $_[1] ) or do {
         $NS->__THROW('Pipe');
     };
+
+    return $ok;
 }
 
 my $DEFAULT_BINMODE_LAYER = ':raw';    #cf. perldoc -f binmode
@@ -680,37 +741,43 @@ sub binmode {
     }
 
     local ( $!, $^E );
-    return binmode( $fh_r, $layer ) || do {
+    my $ok = CORE::binmode( $fh_r, $layer ) or do {
         $NS->__THROW( 'Binmode', layer => $layer );
     };
+
+    return $ok;
 }
 
 sub utime {
     my ( $NS, $atime, $mtime, @files ) = @_;
 
     local ( $!, $^E );
-    return utime( $atime, $mtime, @files ) || do {
+    my $ok = CORE::utime( $atime, $mtime, @files ) or do {
         $NS->__THROW( 'Utime', atime => $atime, mtime => $mtime, files => \@files );
     };
+
+    return $ok;
 }
 
 sub fcntl {
     my ( $NS, $fh, $func, $scalar ) = @_;
 
     local ( $!, $^E );
-    return fcntl( $fh, $func, $scalar ) || do {
+    my $ok = fcntl( $fh, $func, $scalar ) or do {
         $NS->__THROW('Fcntl');
     };
+
+    return $ok;
 }
 
 sub select {
-    my ( $NS, $rbits_r, $wbits_r, $ebits_r, $timeout ) = ( shift, \$_[0], \$_[1], \$_[2], $_[3] );
+    my ( $NS, $timeout ) = ( shift, $_[3] );
 
     #Perl::Critic says not to use one-arg select() anyway.
     die "Need four args!" if @_ < 4;
 
     local ( $!, $^E );
-    my ( $nfound, $timeleft ) = CORE::select( $$rbits_r, $$wbits_r, $$ebits_r, $timeout );
+    my ( $nfound, $timeleft ) = CORE::select( $_[0], $_[1], $_[2], $timeout );
 
     if ($^E) {
         $NS->__THROW('Select');
@@ -722,48 +789,64 @@ sub select {
 #----------------------------------------------------------------------
 
 sub socket {
-    my ( $NS, $socket_r, $domain, $type, $protocol ) = ( shift, \shift, shift, shift, shift );
+    my ( $NS, $domain, $type, $protocol ) = ( shift, @_[ 1 .. $#_ ] );
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $socket_r, $domain, $type, $protocol ) = ( shift, \shift, shift, shift, shift );
 
     local ( $!, $^E );
-    return socket( $$socket_r, $domain, $type, $protocol ) || do {
+    my $ok = CORE::socket( $_[0], $domain, $type, $protocol ) or do {
         $NS->__THROW( 'SocketOpen', domain => $domain, type => $type, protocol => $protocol );
     };
+
+    return $ok;
 }
 
 sub socketpair {
-    my ( $NS, $socket1_r, $socket2_r, $domain, $type, $protocol ) = ( \shift, shift, shift, shift );
+    my ( $NS, $domain, $type, $protocol ) = ( shift, @_[ 2 .. $#_ ] );
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $socket1_r, $socket2_r, $domain, $type, $protocol ) = ( \shift, \shift, shift, shift );
 
     local ( $!, $^E );
-    return socketpair( $$socket1_r, $$socket2_r, $domain, $type, $protocol ) || do {
+    my $ok = CORE::socketpair( $_[0], $_[1], $domain, $type, $protocol ) or do {
         $NS->__THROW( 'SocketPair', domain => $domain, type => $type, protocol => $protocol );
     };
+
+    return $ok;
 }
 
 sub bind {
     my ( $NS, $socket, $name ) = @_;
 
     local ( $!, $^E );
-    return CORE::bind( $socket, $name ) || do {
+    my $ok = CORE::bind( $socket, $name ) or do {
         $NS->__THROW( 'SocketBind', name => $name );
     };
+
+    return $ok;
 }
 
 sub connect {
     my ( $NS, $socket, $name ) = @_;
 
     local ( $!, $^E );
-    return CORE::connect( $socket, $name ) || do {
+    my $ok = CORE::connect( $socket, $name ) or do {
         $NS->__THROW( 'SocketConnect', name => $name );
     };
+
+    return $ok;
 }
 
 sub accept {
     my ( $NS, $new_socket, $generic_socket ) = @_;
 
     local ( $!, $^E );
-    return CORE::accept( $new_socket, $generic_socket ) || do {
+    my $ok = CORE::accept( $new_socket, $generic_socket ) or do {
         $NS->__THROW('SocketAccept');
     };
+
+    return $ok;
 }
 
 sub getsockopt {
@@ -794,16 +877,21 @@ sub listen {
     my ( $NS, $socket, $queuesize ) = @_;
 
     local ( $!, $^E );
-    return CORE::listen( $socket, $queuesize ) || do {
+    my $ok = CORE::listen( $socket, $queuesize ) or do {
         $NS->__THROW( 'SocketListen', queuesize => $queuesize );
     };
+
+    return $ok;
 }
 
 sub recv {
-    my ( $NS, $socket, $scalar_r, $length, $flags ) = ( shift, \shift, @_ );
+    my ( $NS, $socket, $length, $flags ) = ( shift, shift, @_[ 1 .. $#_ ] );
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $socket, $scalar_r, $length, $flags ) = ( shift, shift, \shift, @_ );
 
     local ( $!, $^E );
-    my $res = CORE::recv( $socket, $$scalar_r, $length, $flags );
+    my $res = CORE::recv( $socket, $_[0], $length, $flags );
     if ( !defined $res ) {
         $NS->__THROW( 'SocketReceive', length => $length, flags => $flags );
     }
@@ -812,19 +900,22 @@ sub recv {
 }
 
 sub send {
-    my ( $NS, $socket, $msg_r, $flags, $to ) = ( shift, \shift, @_ );
+    my ( $NS, $socket, $flags, $to ) = ( shift, shift, @_[ 1 .. $#_ ] );
+
+    #https://github.com/pjcj/Devel--Cover/issues/125
+    #my ( $NS, $socket, $msg_r, $flags, $to ) = ( shift, shift, \shift, @_ );
 
     local ( $!, $^E );
     my $res;
     if ( defined $to ) {
-        $res = CORE::send( $socket, $$msg_r, $flags, $to );
+        $res = CORE::send( $socket, $_[0], $flags, $to );
     }
     else {
-        $res = CORE::send( $socket, $$msg_r, $flags );
+        $res = CORE::send( $socket, $_[0], $flags );
     }
 
     if ( !defined $res ) {
-        $NS->__THROW( 'SocketSend', length => length($$msg_r), flags => $flags );
+        $NS->__THROW( 'SocketSend', length => length( $_[0] ), flags => $flags );
     }
 
     return $res;
